# Constraint

The Constraint commands define constraints between regions of the model.

## Create constraints

```{eval-rst}
.. autoclass:: abaqus.Constraint.ConstraintModel.ConstraintModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### Constraint

```{eval-rst}
.. autoclass:: abaqus.Constraint.Constraint.Constraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AdjustPoints

```{eval-rst}
.. autoclass:: abaqus.Constraint.AdjustPoints.AdjustPoints
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

### Coupling

```{eval-rst}
.. autoclass:: abaqus.Constraint.Coupling.Coupling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### DisplayBody

```{eval-rst}
.. autoclass:: abaqus.Constraint.DisplayBody.DisplayBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EmbeddedRegion

```{eval-rst}
.. autoclass:: abaqus.Constraint.EmbeddedRegion.EmbeddedRegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Equation

```{eval-rst}
.. autoclass:: abaqus.Constraint.Equation.Equation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MultipointConstraint

```{eval-rst}
.. autoclass:: abaqus.Constraint.MultipointConstraint.MultipointConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### RigidBody

```{eval-rst}
.. autoclass:: abaqus.Constraint.RigidBody.RigidBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ShellSolidCoupling

```{eval-rst}
.. autoclass:: abaqus.Constraint.ShellSolidCoupling.ShellSolidCoupling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Tie

```{eval-rst}
.. autoclass:: abaqus.Constraint.Tie.Tie
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
